@@ -2,7 +2,7 @@
  *             Finite Element Method Object Library            *
  *              class p1c2d : declaration for p1c2d            *
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.0.0	               *
+ *	             GNU/linux version 3.2.0	               *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2003,2004,2005,2006 CREUSE Emmanuel
@@ -55,7 +55,7 @@
 	     copyright \htmlonly &#169; 2003, 2004, 2005, 2006 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2011, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2003-2012
     \bug none
     \warning none
@@ -311,7 +311,7 @@ int p1c2d<T>::operator () (int num_element, int j) const
 //======================================================
 {
   assert ((j >= 1) && (j <= DofNumber_) && (num_element >= 1) && (num_element <= nbelement_));
-  return number (element[num_element-1][j]);
+  return this -> number (element[num_element-1][j]);
 }
 
 
@@ -427,7 +427,7 @@ void p1c2d<T>::DUDV (matrix_type<T> & mat) const
     { Stiff = LocalStiffnessMatrix (k);
       for (int i=1; i<=DofNumber_; i++)
 	for (int j=1; j<=DofNumber_; j++)
-	  mat (number(element[k-1][i]), number(element[k-1][j])) += Stiff (i,j);
+	  mat (this->number(element[k-1][i]), this->number(element[k-1][j])) += Stiff (i,j);
     }
 }
 
@@ -494,7 +494,7 @@ vector<T> p1c2d<T>::B (T (*f)(T,T), int NbIntPts) const
   for (int k=1; k<=nbelement_; k++)
     { Bloc = BuildBloc (f, k, itg);
       for (int i=1; i<=DofNumber_; i++)
-	B_[number(element[k-1][i])] += Bloc[i];
+	B_[this->number(element[k-1][i])] += Bloc[i];
     }
 
   return B_;
@@ -554,7 +554,7 @@ T p1c2d<T>::error_L2_loc (T (*u)(T,T), const vector<T>& uh, int NbIntPts, int nu
 	  Basis = BasisFunction (xk, xl);
           SumK = 0;
 	  for (int i=1; i<=DofNumber_; i++)
-	    SumK += uh[number(element[num_element-1][i])] * Basis[i];
+	    SumK += uh[this -> number(element[num_element-1][i])] * Basis[i];
 	  Fxkl = Fk (xk, xl, num_element);
 	  LocalError += omegak * omegal * (1-xk) * pow (u (Fxkl[1], Fxkl[2]) - SumK, 2);
 	}
@@ -599,7 +599,7 @@ T p1c2d<T>::error_L2 (T (*u)(T,T), const vector<T>& uh, int NbIntPts) const
 	      Basis = BasisFunction (xk, xl);
 	      SumK = 0;
 	      for (int i=1; i<=DofNumber_; i++)
-		SumK += uh[number(element[num_element-1][i])] * Basis[i];
+		SumK += uh[this->number(element[num_element-1][i])] * Basis[i];
 	      Fxkl = Fk (xk, xl, num_element);
 	      LocalError += omegak * omegal * (1-xk) * pow (u (Fxkl[1], Fxkl[2]) - SumK, 2);
 	    }
@@ -653,8 +653,8 @@ T p1c2d<T>::error_semi_H1 (T (*dudx)(T,T), T (*dudy)(T,T), const vector<T>& uh,
 	      duhdxhat = 0;
 	      duhdyhat = 0;
 	      for (int i=1; i<=DofNumber_; i++)
-		{ duhdxhat += uh[number(element[num_element-1][i])] * DiffBasis (1,i);
-		  duhdyhat += uh[number(element[num_element-1][i])] * DiffBasis (2,i);
+		{ duhdxhat += uh[this->number(element[num_element-1][i])] * DiffBasis (1,i);
+		  duhdyhat += uh[this->number(element[num_element-1][i])] * DiffBasis (2,i);
 		}
 	      duhdx = duhdxhat * InvMk (1,1) + duhdyhat * InvMk (2,1);
 	      duhdy = duhdxhat * InvMk (1,2) + duhdyhat * InvMk (2,2);
@@ -732,8 +732,8 @@ T p1c2d<T>::Grad_Normal_Jump_L2 (const vector<T>& uh, int num_element) const
   duhdxhat1 = 0;
   duhdyhat1 = 0;
   for (int i=1; i<=DofNumber_; i++)
-    { duhdxhat1 += uh[number(element[num_element-1][i])] * DiffBasis (1,i);
-      duhdyhat1 += uh[number(element[num_element-1][i])] * DiffBasis (2,i);
+    { duhdxhat1 += uh[this->number(element[num_element-1][i])] * DiffBasis (1,i);
+      duhdyhat1 += uh[this->number(element[num_element-1][i])] * DiffBasis (2,i);
     }
   duhdx1 = duhdxhat1 * InvMk1 (1,1) + duhdyhat1 * InvMk1 (2,1);
   duhdy1 = duhdxhat1 * InvMk1 (1,2) + duhdyhat1 * InvMk1 (2,2);
@@ -748,8 +748,8 @@ T p1c2d<T>::Grad_Normal_Jump_L2 (const vector<T>& uh, int num_element) const
 	  duhdxhat2 = 0;
 	  duhdyhat2 = 0;
 	  for (int i=1; i<=DofNumber_; i++)
-	    { duhdxhat2 += uh[number(element[jelement-1][i])] * DiffBasis (1,i);
-	      duhdyhat2 += uh[number(element[jelement-1][i])] * DiffBasis (2,i);
+	    { duhdxhat2 += uh[this->number(element[jelement-1][i])] * DiffBasis (1,i);
+	      duhdyhat2 += uh[this->number(element[jelement-1][i])] * DiffBasis (2,i);
 	    }
 	  duhdx2 = duhdxhat2 * InvMk2 (1,1) + duhdyhat2 * InvMk2 (2,1);
 	  duhdy2 = duhdxhat2 * InvMk2 (1,2) + duhdyhat2 * InvMk2 (2,2);
