@@ -2,7 +2,7 @@
  *                 Finite Element Method Object Library        *
  *           class p2c2d : declaration for p2c2d               *
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 	3.0.0                  *
+ *	             GNU/linux version 	3.2.0                  *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2006 CREUSE Emmanuel
@@ -55,7 +55,7 @@
 	     copyright \htmlonly &#169; 2006 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2005-2012
     \bug none
     \warning none
@@ -461,7 +461,7 @@ int p2c2d<T>::operator () (int num_element, int j) const
   assert ((j >= 1) && (j <= DofNumber_) && (num_element >= 1) && (num_element <= nbelement_));
 
   if (j <= 3)
-    return number (element[num_element-1][j]);
+    return this -> number (element[num_element-1][j]);
   else
     return EdgesPerTriangle_(num_element, j-3) + nbvertex_;
 }
@@ -518,13 +518,13 @@ void p2c2d<T>::DUDV (matrix_type<T> & mat) const
     { Stiff = LocalStiffnessMatrix (k);
       for (int i=1; i<=3; i++)
 	for (int j=1; j<=3; j++)
-	  mat (number (element[k-1][i]), number (element[k-1][j])) += Stiff (i,j);
+	  mat (this -> number (element[k-1][i]), this ->number (element[k-1][j])) += Stiff (i,j);
       for (int i=1; i<=3; i++)
 	for (int j=4; j<=6; j++)
-	  mat (number (element[k-1][i]), EdgesPerTriangle_(k,j-3) + nbvertex_) += Stiff (i,j);
+	  mat (this -> number (element[k-1][i]), EdgesPerTriangle_(k,j-3) + nbvertex_) += Stiff (i,j);
       for (int i=4; i<=6; i++)
 	for (int j=1; j<=3; j++)
-	  mat (EdgesPerTriangle_(k,i-3) + nbvertex_, number (element[k-1][j])) += Stiff (i,j); 
+	  mat (EdgesPerTriangle_(k,i-3) + nbvertex_, this -> number (element[k-1][j])) += Stiff (i,j); 
       for(int i=4; i<=6; i++)
 	for (int j=4; j<=6; j++)
 	  mat (EdgesPerTriangle_(k,i-3) + nbvertex_, EdgesPerTriangle_(k,j-3) + nbvertex_) += Stiff (i,j);  
@@ -591,7 +591,7 @@ vector<T> p2c2d<T>::B (T (*f)(T,T), int NbIntPts) const
   for (int k=1; k<=nbelement_; k++)
     { Bloc = BuildBloc (f, k, itg);
       for (int i=1; i<=3; i++)
-	B_[number(element[k-1][i])] += Bloc[i];
+	B_[this->number(element[k-1][i])] += Bloc[i];
       for (int i=4; i<=6; i++)
 	B_[ EdgesPerTriangle_(k,i-3)+nbvertex_] += Bloc[i];
     }
@@ -670,7 +670,7 @@ T p2c2d<T>::error_L2 (T (*u)(T,T), const vector<T>& uh, int NbIntPts) const
 	      Basis = BasisFunction (xk, xl);
 	      SumK = 0;
 	      for (int i=1; i<=3; i++)
-		SumK += uh [number (element[num_element-1][i])] * Basis[i];
+		SumK += uh [this -> number (element[num_element-1][i])] * Basis[i];
 	      for (int i=4; i<=6; i++)
 		SumK += uh [EdgesPerTriangle_(num_element, i-3) + nbvertex_] * Basis[i];
 	      Fxkl = Fk (xk, xl, num_element);
@@ -724,8 +724,8 @@ T p2c2d<T>::error_semi_H1 (T (*dudx)(T,T), T (*dudy)(T,T), const vector<T>& uh,
 	      duhdxhat = 0;
 	      duhdyhat = 0;
 	      for (int i=1; i<=3; i++)
-		{ duhdxhat += uh [number (element[num_element-1][i])] * DiffBasis (1,i);
-		  duhdyhat += uh [number (element[num_element-1][i])] * DiffBasis (2,i);
+		{ duhdxhat += uh [this -> number (element[num_element-1][i])] * DiffBasis (1,i);
+		  duhdyhat += uh [this -> number (element[num_element-1][i])] * DiffBasis (2,i);
 		}
 	      for (int i=4; i<=6; i++)
 		{ duhdxhat += uh [EdgesPerTriangle_(num_element,i-3) + nbvertex_ ] * DiffBasis (1,i);
