@@ -2,7 +2,7 @@
  *             Finite Element Method Object Library            *
  *              class q12d : declaration for q12d              *
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.0.0	               *
+ *	             GNU/linux version 3.2.0	               *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2004 CREUSE Emmanuel
@@ -57,7 +57,7 @@
 	     copyright \htmlonly &#169; 2004 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2004 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2004-2012
     \bug none
     \warning none
@@ -281,7 +281,7 @@ int q12d<T>::operator () (int num_element, int j) const
 {
   assert ((j >= 1) && (j <= DofNumber_) && (num_element >= 1) && (num_element <= nbelement_));
 
-  return number (element[num_element-1][j]);
+  return this -> number (element[num_element-1][j]);
 }
 
 
