@@ -2,7 +2,7 @@
  *             Finite Element Method Object Library            *
  *       class mesh_tri_2d : declaration for mesh_tri_2d       *
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.0.0                   *
+ *	             GNU/linux version 3.2.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2005,2006 CREUSE Emmanuel
@@ -59,7 +59,7 @@
 	     copyright \htmlonly &#169; 2005, 2006 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2005-2012
     \bug none
     \warning none
@@ -211,8 +211,8 @@ mesh_tri_2d<T>::mesh_tri_2d (const char* file1, const char* file2) : mesh <trian
 
   for (int k=1; k<=nbelement_; k++)
     for (int edge_number=1; edge_number<=3; edge_number++)
-      { int i = number (element[k-1][VertexOfEdge(edge_number,1)]);
-	int j = number (element[k-1][VertexOfEdge(edge_number,2)]);
+      { int i = this -> number (element[k-1][VertexOfEdge(edge_number,1)]);
+	int j = this -> number (element[k-1][VertexOfEdge(edge_number,2)]);
 	if (j < i)
 	  { tmp = i;
 	    i = j;
@@ -269,7 +269,7 @@ mesh_tri_2d<T>::mesh_tri_2d (const char* file1, const char* file2) : mesh <trian
       { numseg = EdgesPerTriangle_ (jt, j);
 	num_node_1 = SetOfEdges_(numseg, 1);
 	num_node_2 = SetOfEdges_(numseg, 2);
-	num_node_in_front = number(element[jt-1][j]);
+	num_node_in_front = this -> number (element[jt-1][j]);
 	if ((vertices[num_node_2-1] - vertices[num_node_1-1]).ortho2D() * (vertices[num_node_in_front-1] - vertices[num_node_1-1]) > 0)
 	  NormalDirection_ (jt, j) = -1;
 	else
@@ -462,7 +462,7 @@ int mesh_tri_2d<T>::num_loc (int num_element, int num_node) const
 {
   int num = 0;
   for (int j=1; j<=3; j++)
-    if (number (element[num_element-1][j]) == num_node)
+    if (this -> number (element[num_element-1][j]) == num_node)
       { num = j;
 	return num;
       }
@@ -748,8 +748,8 @@ void mesh_tri_2d<T>::refine_mesh (vector<int>& TABTRI)
 
   for (int k=1; k<=nbelement_; k++)
     for (int edge_number=1; edge_number<=3; edge_number++)
-      { int i = number (element[k-1][VertexOfEdge(edge_number,1)]);
-	int j = number (element[k-1][VertexOfEdge(edge_number,2)]);
+      { int i = this -> number (element[k-1][VertexOfEdge(edge_number,1)]);
+	int j = this -> number (element[k-1][VertexOfEdge(edge_number,2)]);
 	if (j < i)
 	  { tmp = i;
 	    i = j;
@@ -812,7 +812,7 @@ void mesh_tri_2d<T>::refine_mesh (vector<int>& TABTRI)
       { numseg = EdgesPerTriangle_ (jt, j);
 	num_node_1 = SetOfEdges_ (numseg, 1);
 	num_node_2 = SetOfEdges_ (numseg, 2);
-	num_node_in_front = number (element[jt-1][j]);
+	num_node_in_front = this -> number (element[jt-1][j]);
 	if ((vertices[num_node_2-1] - vertices[num_node_1-1]).ortho2D() * (vertices[num_node_in_front-1] - vertices[num_node_1-1]) > 0)
 	  NormalDirection_ (jt, j) = -1;
 	else
@@ -1317,8 +1317,8 @@ void mesh_tri_2d<T>::refine_mesh_angle (vector<int>& TABTRI, T MinAngle)
 
   for (int k=1; k<=nbelement_; k++)
     for(int edge_number=1; edge_number<=3; edge_number++)
-      { int i = number (element[k-1][VertexOfEdge(edge_number,1)]);
-	int j = number (element[k-1][VertexOfEdge(edge_number,2)]);
+      { int i = this -> number (element[k-1][VertexOfEdge(edge_number,1)]);
+	int j = this -> number (element[k-1][VertexOfEdge(edge_number,2)]);
 	if (j < i)
 	  { tmp = i;
 	    i = j;
@@ -1383,7 +1383,7 @@ void mesh_tri_2d<T>::refine_mesh_angle (vector<int>& TABTRI, T MinAngle)
       { numseg = EdgesPerTriangle_(jt,j);
 	num_node_1 = SetOfEdges_(numseg,1);
 	num_node_2 = SetOfEdges_(numseg,2);
-	num_node_in_front = number(element[jt-1][j]);
+	num_node_in_front = this -> number(element[jt-1][j]);
 	if ((vertices[num_node_2-1] - vertices[num_node_1-1]).ortho2D() * (vertices[num_node_in_front-1] - vertices[num_node_1-1]) > 0)
 	  NormalDirection_(jt,j) = -1;
 	else
