@@ -2,7 +2,7 @@
  *             Finite Element Method Object Library            *
  *                          tutorial 4                         *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 	2.6.0                  *
+ *	             GNU/linux version 	3.2.0                  *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2006 CREUSE Emmanuel
@@ -48,58 +48,54 @@
 	     copyright \htmlonly &#169; 2006 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
 	     copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 2.6.0
+    \version 3.2.0
     \date 2006-2012
     \bug none
     \warning none
 */
 
-#if !defined(__IOSTREAM_H)
+#ifndef __iostream
 #include <iostream>
 #endif
 
-#if !defined(__STRING_H)
+#ifndef __string
 #include <string>
 #endif
 
-#if !defined(__ASSERT_H)
+#ifndef __assert_h
 #include <assert.h>
 #endif
 
-#if !defined(__TIME_H)
+#ifndef __time_h
 #include <time.h>
 #endif
 
-#if !defined(__MATHS_H)
-#include "MOL++/maths.h"
+#ifndef __vectors_hpp
+#include "MOL++/vectors.hpp"
 #endif
 
-#if !defined(__VECTORS_H)
-#include "MOL++/vectors.h"
+#ifndef __integration_hpp
+#include "MOL++/integration.hpp"
 #endif
 
-#if !defined(__INTEGRATION_H)
-#include "MOL++/integration.h"
+#ifndef __convert_hpp
+#include "FEMOL++/meshes/convert.hpp"
 #endif
 
-#if !defined(__CONVERT_H)
-#include "FEMOL++/meshes/convert.h"
+#ifndef __mesh_tri_2d_hpp
+#include "FEMOL++/meshes/mesh_tri_2d.hpp"
 #endif
 
-#if !defined(__MESH_TRI_2D_H)
-#include "FEMOL++/meshes/mesh_tri_2d.h"
+#ifndef __triangle_hpp
+#include "FEMOL++/meshes/triangle.hpp"
 #endif
 
-#if !defined(__TRIANGLE_H)
-#include "FEMOL++/meshes/triangle.h"
+#ifndef __rt2d_hpp
+#include "FEMOL++/elements/rt02d.hpp"
 #endif
 
-#if !defined(__TRIANGLE_H)
-#include "FEMOL++/elements/rt02d.h"
-#endif
-
-#if !defined(__AFFICHE_H)
-#include "tests/affiche.h"
+#ifndef __affiche_hpp
+#include "tests/affiche.hpp"
 #endif
 
 using namespace std;
